# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sensor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sensor.proto',
  package='reachy.sdk.joint',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0csensor.proto\x12\x10reachy.sdk.joint\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"/\n\x08SensorId\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\r\n\x03uid\x18\x02 \x01(\rH\x00\x42\x04\n\x02id\"(\n\tSensorsId\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0c\n\x04uids\x18\x02 \x03(\r\"!\n\x10\x46orceSensorState\x12\r\n\x05\x66orce\x18\x01 \x01(\x02\"X\n\x0bSensorState\x12@\n\x12\x66orce_sensor_state\x18\x01 \x01(\x0b\x32\".reachy.sdk.joint.ForceSensorStateH\x00\x42\x07\n\x05state\"\x95\x01\n\x0cSensorsState\x12\'\n\x03ids\x18\x01 \x03(\x0b\x32\x1a.reachy.sdk.joint.SensorId\x12-\n\x06states\x18\x02 \x03(\x0b\x32\x1d.reachy.sdk.joint.SensorState\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"m\n\x13SensorsStateRequest\x12\'\n\x03ids\x18\x01 \x03(\x0b\x32\x1a.reachy.sdk.joint.SensorId\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x19StreamSensorsStateRequest\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32%.reachy.sdk.joint.SensorsStateRequest\x12\x19\n\x11publish_frequency\x18\x02 \x01(\x02\x32\x9b\x02\n\rSensorService\x12K\n\x14GetAllForceSensorsId\x12\x16.google.protobuf.Empty\x1a\x1b.reachy.sdk.joint.SensorsId\x12X\n\x0fGetSensorsState\x12%.reachy.sdk.joint.SensorsStateRequest\x1a\x1e.reachy.sdk.joint.SensorsState\x12\x63\n\x12StreamSensorStates\x12+.reachy.sdk.joint.StreamSensorsStateRequest\x1a\x1e.reachy.sdk.joint.SensorsState0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_SENSORID = _descriptor.Descriptor(
  name='SensorId',
  full_name='reachy.sdk.joint.SensorId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='reachy.sdk.joint.SensorId.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='reachy.sdk.joint.SensorId.uid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='reachy.sdk.joint.SensorId.id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=96,
  serialized_end=143,
)


_SENSORSID = _descriptor.Descriptor(
  name='SensorsId',
  full_name='reachy.sdk.joint.SensorsId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='names', full_name='reachy.sdk.joint.SensorsId.names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uids', full_name='reachy.sdk.joint.SensorsId.uids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=185,
)


_FORCESENSORSTATE = _descriptor.Descriptor(
  name='ForceSensorState',
  full_name='reachy.sdk.joint.ForceSensorState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='force', full_name='reachy.sdk.joint.ForceSensorState.force', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=220,
)


_SENSORSTATE = _descriptor.Descriptor(
  name='SensorState',
  full_name='reachy.sdk.joint.SensorState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='force_sensor_state', full_name='reachy.sdk.joint.SensorState.force_sensor_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='state', full_name='reachy.sdk.joint.SensorState.state',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=222,
  serialized_end=310,
)


_SENSORSSTATE = _descriptor.Descriptor(
  name='SensorsState',
  full_name='reachy.sdk.joint.SensorsState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='reachy.sdk.joint.SensorsState.ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='states', full_name='reachy.sdk.joint.SensorsState.states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.joint.SensorsState.timestamp', index=2,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=462,
)


_SENSORSSTATEREQUEST = _descriptor.Descriptor(
  name='SensorsStateRequest',
  full_name='reachy.sdk.joint.SensorsStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='reachy.sdk.joint.SensorsStateRequest.ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.joint.SensorsStateRequest.timestamp', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=464,
  serialized_end=573,
)


_STREAMSENSORSSTATEREQUEST = _descriptor.Descriptor(
  name='StreamSensorsStateRequest',
  full_name='reachy.sdk.joint.StreamSensorsStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='reachy.sdk.joint.StreamSensorsStateRequest.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publish_frequency', full_name='reachy.sdk.joint.StreamSensorsStateRequest.publish_frequency', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=685,
)

_SENSORID.oneofs_by_name['id'].fields.append(
  _SENSORID.fields_by_name['name'])
_SENSORID.fields_by_name['name'].containing_oneof = _SENSORID.oneofs_by_name['id']
_SENSORID.oneofs_by_name['id'].fields.append(
  _SENSORID.fields_by_name['uid'])
_SENSORID.fields_by_name['uid'].containing_oneof = _SENSORID.oneofs_by_name['id']
_SENSORSTATE.fields_by_name['force_sensor_state'].message_type = _FORCESENSORSTATE
_SENSORSTATE.oneofs_by_name['state'].fields.append(
  _SENSORSTATE.fields_by_name['force_sensor_state'])
_SENSORSTATE.fields_by_name['force_sensor_state'].containing_oneof = _SENSORSTATE.oneofs_by_name['state']
_SENSORSSTATE.fields_by_name['ids'].message_type = _SENSORID
_SENSORSSTATE.fields_by_name['states'].message_type = _SENSORSTATE
_SENSORSSTATE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SENSORSSTATEREQUEST.fields_by_name['ids'].message_type = _SENSORID
_SENSORSSTATEREQUEST.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMSENSORSSTATEREQUEST.fields_by_name['request'].message_type = _SENSORSSTATEREQUEST
DESCRIPTOR.message_types_by_name['SensorId'] = _SENSORID
DESCRIPTOR.message_types_by_name['SensorsId'] = _SENSORSID
DESCRIPTOR.message_types_by_name['ForceSensorState'] = _FORCESENSORSTATE
DESCRIPTOR.message_types_by_name['SensorState'] = _SENSORSTATE
DESCRIPTOR.message_types_by_name['SensorsState'] = _SENSORSSTATE
DESCRIPTOR.message_types_by_name['SensorsStateRequest'] = _SENSORSSTATEREQUEST
DESCRIPTOR.message_types_by_name['StreamSensorsStateRequest'] = _STREAMSENSORSSTATEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SensorId = _reflection.GeneratedProtocolMessageType('SensorId', (_message.Message,), {
  'DESCRIPTOR' : _SENSORID,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorId)
  })
_sym_db.RegisterMessage(SensorId)

SensorsId = _reflection.GeneratedProtocolMessageType('SensorsId', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSID,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorsId)
  })
_sym_db.RegisterMessage(SensorsId)

ForceSensorState = _reflection.GeneratedProtocolMessageType('ForceSensorState', (_message.Message,), {
  'DESCRIPTOR' : _FORCESENSORSTATE,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.ForceSensorState)
  })
_sym_db.RegisterMessage(ForceSensorState)

SensorState = _reflection.GeneratedProtocolMessageType('SensorState', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSTATE,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorState)
  })
_sym_db.RegisterMessage(SensorState)

SensorsState = _reflection.GeneratedProtocolMessageType('SensorsState', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSSTATE,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorsState)
  })
_sym_db.RegisterMessage(SensorsState)

SensorsStateRequest = _reflection.GeneratedProtocolMessageType('SensorsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSSTATEREQUEST,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorsStateRequest)
  })
_sym_db.RegisterMessage(SensorsStateRequest)

StreamSensorsStateRequest = _reflection.GeneratedProtocolMessageType('StreamSensorsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSENSORSSTATEREQUEST,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.StreamSensorsStateRequest)
  })
_sym_db.RegisterMessage(StreamSensorsStateRequest)



_SENSORSERVICE = _descriptor.ServiceDescriptor(
  name='SensorService',
  full_name='reachy.sdk.joint.SensorService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=688,
  serialized_end=971,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAllForceSensorsId',
    full_name='reachy.sdk.joint.SensorService.GetAllForceSensorsId',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_SENSORSID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSensorsState',
    full_name='reachy.sdk.joint.SensorService.GetSensorsState',
    index=1,
    containing_service=None,
    input_type=_SENSORSSTATEREQUEST,
    output_type=_SENSORSSTATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamSensorStates',
    full_name='reachy.sdk.joint.SensorService.StreamSensorStates',
    index=2,
    containing_service=None,
    input_type=_STREAMSENSORSSTATEREQUEST,
    output_type=_SENSORSSTATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SENSORSERVICE)

DESCRIPTOR.services_by_name['SensorService'] = _SENSORSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fullbody_cartesian_command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import arm_kinematics_pb2 as arm__kinematics__pb2
import orbita_kinematics_pb2 as orbita__kinematics__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fullbody_cartesian_command.proto',
  package='reachy.sdk.kinematics',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n fullbody_cartesian_command.proto\x12\x15reachy.sdk.kinematics\x1a\x14\x61rm_kinematics.proto\x1a\x17orbita_kinematics.proto\"\x80\x01\n\x1b\x46ullBodyCartesianCommandAck\x12 \n\x18left_arm_command_success\x18\x01 \x01(\x08\x12!\n\x19right_arm_command_success\x18\x02 \x01(\x08\x12\x1c\n\x14neck_command_success\x18\x03 \x01(\x08\"\xbf\x01\n\x18\x46ullBodyCartesianCommand\x12\x35\n\x08left_arm\x18\x01 \x01(\x0b\x32#.reachy.sdk.kinematics.ArmIKRequest\x12\x36\n\tright_arm\x18\x02 \x01(\x0b\x32#.reachy.sdk.kinematics.ArmIKRequest\x12\x34\n\x04neck\x18\x03 \x01(\x0b\x32&.reachy.sdk.kinematics.OrbitaIKRequest2\xb3\x02\n\x1f\x46ullBodyCartesianCommandService\x12\x84\x01\n\x1dSendFullBodyCartesianCommands\x12/.reachy.sdk.kinematics.FullBodyCartesianCommand\x1a\x32.reachy.sdk.kinematics.FullBodyCartesianCommandAck\x12\x88\x01\n\x1fStreamFullBodyCartesianCommands\x12/.reachy.sdk.kinematics.FullBodyCartesianCommand\x1a\x32.reachy.sdk.kinematics.FullBodyCartesianCommandAck(\x01\x62\x06proto3'
  ,
  dependencies=[arm__kinematics__pb2.DESCRIPTOR,orbita__kinematics__pb2.DESCRIPTOR,])




_FULLBODYCARTESIANCOMMANDACK = _descriptor.Descriptor(
  name='FullBodyCartesianCommandAck',
  full_name='reachy.sdk.kinematics.FullBodyCartesianCommandAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='left_arm_command_success', full_name='reachy.sdk.kinematics.FullBodyCartesianCommandAck.left_arm_command_success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_arm_command_success', full_name='reachy.sdk.kinematics.FullBodyCartesianCommandAck.right_arm_command_success', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='neck_command_success', full_name='reachy.sdk.kinematics.FullBodyCartesianCommandAck.neck_command_success', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=235,
)


_FULLBODYCARTESIANCOMMAND = _descriptor.Descriptor(
  name='FullBodyCartesianCommand',
  full_name='reachy.sdk.kinematics.FullBodyCartesianCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='left_arm', full_name='reachy.sdk.kinematics.FullBodyCartesianCommand.left_arm', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_arm', full_name='reachy.sdk.kinematics.FullBodyCartesianCommand.right_arm', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='neck', full_name='reachy.sdk.kinematics.FullBodyCartesianCommand.neck', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=429,
)

_FULLBODYCARTESIANCOMMAND.fields_by_name['left_arm'].message_type = arm__kinematics__pb2._ARMIKREQUEST
_FULLBODYCARTESIANCOMMAND.fields_by_name['right_arm'].message_type = arm__kinematics__pb2._ARMIKREQUEST
_FULLBODYCARTESIANCOMMAND.fields_by_name['neck'].message_type = orbita__kinematics__pb2._ORBITAIKREQUEST
DESCRIPTOR.message_types_by_name['FullBodyCartesianCommandAck'] = _FULLBODYCARTESIANCOMMANDACK
DESCRIPTOR.message_types_by_name['FullBodyCartesianCommand'] = _FULLBODYCARTESIANCOMMAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FullBodyCartesianCommandAck = _reflection.GeneratedProtocolMessageType('FullBodyCartesianCommandAck', (_message.Message,), {
  'DESCRIPTOR' : _FULLBODYCARTESIANCOMMANDACK,
  '__module__' : 'fullbody_cartesian_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.FullBodyCartesianCommandAck)
  })
_sym_db.RegisterMessage(FullBodyCartesianCommandAck)

FullBodyCartesianCommand = _reflection.GeneratedProtocolMessageType('FullBodyCartesianCommand', (_message.Message,), {
  'DESCRIPTOR' : _FULLBODYCARTESIANCOMMAND,
  '__module__' : 'fullbody_cartesian_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.FullBodyCartesianCommand)
  })
_sym_db.RegisterMessage(FullBodyCartesianCommand)



_FULLBODYCARTESIANCOMMANDSERVICE = _descriptor.ServiceDescriptor(
  name='FullBodyCartesianCommandService',
  full_name='reachy.sdk.kinematics.FullBodyCartesianCommandService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=432,
  serialized_end=739,
  methods=[
  _descriptor.MethodDescriptor(
    name='SendFullBodyCartesianCommands',
    full_name='reachy.sdk.kinematics.FullBodyCartesianCommandService.SendFullBodyCartesianCommands',
    index=0,
    containing_service=None,
    input_type=_FULLBODYCARTESIANCOMMAND,
    output_type=_FULLBODYCARTESIANCOMMANDACK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamFullBodyCartesianCommands',
    full_name='reachy.sdk.kinematics.FullBodyCartesianCommandService.StreamFullBodyCartesianCommands',
    index=1,
    containing_service=None,
    input_type=_FULLBODYCARTESIANCOMMAND,
    output_type=_FULLBODYCARTESIANCOMMANDACK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FULLBODYCARTESIANCOMMANDSERVICE)

DESCRIPTOR.services_by_name['FullBodyCartesianCommandService'] = _FULLBODYCARTESIANCOMMANDSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: restart_signal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='restart_signal.proto',
  package='reachy.sdk.restart',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14restart_signal.proto\x12\x12reachy.sdk.restart\"9\n\nRestartCmd\x12+\n\x03\x63md\x18\x01 \x01(\x0e\x32\x1e.reachy.sdk.restart.SignalType\"#\n\x10RestartSignalAck\x12\x0f\n\x07success\x18\x01 \x01(\x08*#\n\nSignalType\x12\x0b\n\x07RESTART\x10\x00\x12\x08\n\x04STOP\x10\x01\x32k\n\x0eRestartService\x12Y\n\x11SendRestartSignal\x12\x1e.reachy.sdk.restart.RestartCmd\x1a$.reachy.sdk.restart.RestartSignalAckb\x06proto3'
)

_SIGNALTYPE = _descriptor.EnumDescriptor(
  name='SignalType',
  full_name='reachy.sdk.restart.SignalType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESTART', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=140,
  serialized_end=175,
)
_sym_db.RegisterEnumDescriptor(_SIGNALTYPE)

SignalType = enum_type_wrapper.EnumTypeWrapper(_SIGNALTYPE)
RESTART = 0
STOP = 1



_RESTARTCMD = _descriptor.Descriptor(
  name='RestartCmd',
  full_name='reachy.sdk.restart.RestartCmd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='reachy.sdk.restart.RestartCmd.cmd', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44,
  serialized_end=101,
)


_RESTARTSIGNALACK = _descriptor.Descriptor(
  name='RestartSignalAck',
  full_name='reachy.sdk.restart.RestartSignalAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='reachy.sdk.restart.RestartSignalAck.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=138,
)

_RESTARTCMD.fields_by_name['cmd'].enum_type = _SIGNALTYPE
DESCRIPTOR.message_types_by_name['RestartCmd'] = _RESTARTCMD
DESCRIPTOR.message_types_by_name['RestartSignalAck'] = _RESTARTSIGNALACK
DESCRIPTOR.enum_types_by_name['SignalType'] = _SIGNALTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RestartCmd = _reflection.GeneratedProtocolMessageType('RestartCmd', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTCMD,
  '__module__' : 'restart_signal_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.restart.RestartCmd)
  })
_sym_db.RegisterMessage(RestartCmd)

RestartSignalAck = _reflection.GeneratedProtocolMessageType('RestartSignalAck', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTSIGNALACK,
  '__module__' : 'restart_signal_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.restart.RestartSignalAck)
  })
_sym_db.RegisterMessage(RestartSignalAck)



_RESTARTSERVICE = _descriptor.ServiceDescriptor(
  name='RestartService',
  full_name='reachy.sdk.restart.RestartService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=177,
  serialized_end=284,
  methods=[
  _descriptor.MethodDescriptor(
    name='SendRestartSignal',
    full_name='reachy.sdk.restart.RestartService.SendRestartSignal',
    index=0,
    containing_service=None,
    input_type=_RESTARTCMD,
    output_type=_RESTARTSIGNALACK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RESTARTSERVICE)

DESCRIPTOR.services_by_name['RestartService'] = _RESTARTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arm_kinematics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import kinematics_pb2 as kinematics__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='arm_kinematics.proto',
  package='reachy.sdk.kinematics',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14\x61rm_kinematics.proto\x12\x15reachy.sdk.kinematics\x1a\x10kinematics.proto\"n\n\x0e\x41rmEndEffector\x12,\n\x04side\x18\x01 \x01(\x0e\x32\x1e.reachy.sdk.kinematics.ArmSide\x12.\n\x04pose\x18\x02 \x01(\x0b\x32 .reachy.sdk.kinematics.Matrix4x4\"y\n\x10\x41rmJointPosition\x12,\n\x04side\x18\x01 \x01(\x0e\x32\x1e.reachy.sdk.kinematics.ArmSide\x12\x37\n\tpositions\x18\x02 \x01(\x0b\x32$.reachy.sdk.kinematics.JointPosition\"M\n\x0c\x41rmFKRequest\x12=\n\x0c\x61rm_position\x18\x01 \x01(\x0b\x32\'.reachy.sdk.kinematics.ArmJointPosition\"]\n\rArmFKSolution\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12;\n\x0c\x65nd_effector\x18\x02 \x01(\x0b\x32%.reachy.sdk.kinematics.ArmEndEffector\"w\n\x0c\x41rmIKRequest\x12\x35\n\x06target\x18\x01 \x01(\x0b\x32%.reachy.sdk.kinematics.ArmEndEffector\x12\x30\n\x02q0\x18\x02 \x01(\x0b\x32$.reachy.sdk.kinematics.JointPosition\"_\n\rArmIKSolution\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12=\n\x0c\x61rm_position\x18\x02 \x01(\x0b\x32\'.reachy.sdk.kinematics.ArmJointPosition*\x1e\n\x07\x41rmSide\x12\x08\n\x04LEFT\x10\x00\x12\t\n\x05RIGHT\x10\x01\x32\xc5\x01\n\rArmKinematics\x12Y\n\x0c\x43omputeArmFK\x12#.reachy.sdk.kinematics.ArmFKRequest\x1a$.reachy.sdk.kinematics.ArmFKSolution\x12Y\n\x0c\x43omputeArmIK\x12#.reachy.sdk.kinematics.ArmIKRequest\x1a$.reachy.sdk.kinematics.ArmIKSolutionb\x06proto3'
  ,
  dependencies=[kinematics__pb2.DESCRIPTOR,])

_ARMSIDE = _descriptor.EnumDescriptor(
  name='ArmSide',
  full_name='reachy.sdk.kinematics.ArmSide',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=692,
  serialized_end=722,
)
_sym_db.RegisterEnumDescriptor(_ARMSIDE)

ArmSide = enum_type_wrapper.EnumTypeWrapper(_ARMSIDE)
LEFT = 0
RIGHT = 1



_ARMENDEFFECTOR = _descriptor.Descriptor(
  name='ArmEndEffector',
  full_name='reachy.sdk.kinematics.ArmEndEffector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='side', full_name='reachy.sdk.kinematics.ArmEndEffector.side', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='reachy.sdk.kinematics.ArmEndEffector.pose', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=175,
)


_ARMJOINTPOSITION = _descriptor.Descriptor(
  name='ArmJointPosition',
  full_name='reachy.sdk.kinematics.ArmJointPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='side', full_name='reachy.sdk.kinematics.ArmJointPosition.side', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positions', full_name='reachy.sdk.kinematics.ArmJointPosition.positions', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=298,
)


_ARMFKREQUEST = _descriptor.Descriptor(
  name='ArmFKRequest',
  full_name='reachy.sdk.kinematics.ArmFKRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='arm_position', full_name='reachy.sdk.kinematics.ArmFKRequest.arm_position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=377,
)


_ARMFKSOLUTION = _descriptor.Descriptor(
  name='ArmFKSolution',
  full_name='reachy.sdk.kinematics.ArmFKSolution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='reachy.sdk.kinematics.ArmFKSolution.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_effector', full_name='reachy.sdk.kinematics.ArmFKSolution.end_effector', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=379,
  serialized_end=472,
)


_ARMIKREQUEST = _descriptor.Descriptor(
  name='ArmIKRequest',
  full_name='reachy.sdk.kinematics.ArmIKRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='reachy.sdk.kinematics.ArmIKRequest.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q0', full_name='reachy.sdk.kinematics.ArmIKRequest.q0', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=593,
)


_ARMIKSOLUTION = _descriptor.Descriptor(
  name='ArmIKSolution',
  full_name='reachy.sdk.kinematics.ArmIKSolution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='reachy.sdk.kinematics.ArmIKSolution.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arm_position', full_name='reachy.sdk.kinematics.ArmIKSolution.arm_position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=690,
)

_ARMENDEFFECTOR.fields_by_name['side'].enum_type = _ARMSIDE
_ARMENDEFFECTOR.fields_by_name['pose'].message_type = kinematics__pb2._MATRIX4X4
_ARMJOINTPOSITION.fields_by_name['side'].enum_type = _ARMSIDE
_ARMJOINTPOSITION.fields_by_name['positions'].message_type = kinematics__pb2._JOINTPOSITION
_ARMFKREQUEST.fields_by_name['arm_position'].message_type = _ARMJOINTPOSITION
_ARMFKSOLUTION.fields_by_name['end_effector'].message_type = _ARMENDEFFECTOR
_ARMIKREQUEST.fields_by_name['target'].message_type = _ARMENDEFFECTOR
_ARMIKREQUEST.fields_by_name['q0'].message_type = kinematics__pb2._JOINTPOSITION
_ARMIKSOLUTION.fields_by_name['arm_position'].message_type = _ARMJOINTPOSITION
DESCRIPTOR.message_types_by_name['ArmEndEffector'] = _ARMENDEFFECTOR
DESCRIPTOR.message_types_by_name['ArmJointPosition'] = _ARMJOINTPOSITION
DESCRIPTOR.message_types_by_name['ArmFKRequest'] = _ARMFKREQUEST
DESCRIPTOR.message_types_by_name['ArmFKSolution'] = _ARMFKSOLUTION
DESCRIPTOR.message_types_by_name['ArmIKRequest'] = _ARMIKREQUEST
DESCRIPTOR.message_types_by_name['ArmIKSolution'] = _ARMIKSOLUTION
DESCRIPTOR.enum_types_by_name['ArmSide'] = _ARMSIDE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ArmEndEffector = _reflection.GeneratedProtocolMessageType('ArmEndEffector', (_message.Message,), {
  'DESCRIPTOR' : _ARMENDEFFECTOR,
  '__module__' : 'arm_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.ArmEndEffector)
  })
_sym_db.RegisterMessage(ArmEndEffector)

ArmJointPosition = _reflection.GeneratedProtocolMessageType('ArmJointPosition', (_message.Message,), {
  'DESCRIPTOR' : _ARMJOINTPOSITION,
  '__module__' : 'arm_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.ArmJointPosition)
  })
_sym_db.RegisterMessage(ArmJointPosition)

ArmFKRequest = _reflection.GeneratedProtocolMessageType('ArmFKRequest', (_message.Message,), {
  'DESCRIPTOR' : _ARMFKREQUEST,
  '__module__' : 'arm_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.ArmFKRequest)
  })
_sym_db.RegisterMessage(ArmFKRequest)

ArmFKSolution = _reflection.GeneratedProtocolMessageType('ArmFKSolution', (_message.Message,), {
  'DESCRIPTOR' : _ARMFKSOLUTION,
  '__module__' : 'arm_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.ArmFKSolution)
  })
_sym_db.RegisterMessage(ArmFKSolution)

ArmIKRequest = _reflection.GeneratedProtocolMessageType('ArmIKRequest', (_message.Message,), {
  'DESCRIPTOR' : _ARMIKREQUEST,
  '__module__' : 'arm_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.ArmIKRequest)
  })
_sym_db.RegisterMessage(ArmIKRequest)

ArmIKSolution = _reflection.GeneratedProtocolMessageType('ArmIKSolution', (_message.Message,), {
  'DESCRIPTOR' : _ARMIKSOLUTION,
  '__module__' : 'arm_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.ArmIKSolution)
  })
_sym_db.RegisterMessage(ArmIKSolution)



_ARMKINEMATICS = _descriptor.ServiceDescriptor(
  name='ArmKinematics',
  full_name='reachy.sdk.kinematics.ArmKinematics',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=725,
  serialized_end=922,
  methods=[
  _descriptor.MethodDescriptor(
    name='ComputeArmFK',
    full_name='reachy.sdk.kinematics.ArmKinematics.ComputeArmFK',
    index=0,
    containing_service=None,
    input_type=_ARMFKREQUEST,
    output_type=_ARMFKSOLUTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ComputeArmIK',
    full_name='reachy.sdk.kinematics.ArmKinematics.ComputeArmIK',
    index=1,
    containing_service=None,
    input_type=_ARMIKREQUEST,
    output_type=_ARMIKSOLUTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ARMKINEMATICS)

DESCRIPTOR.services_by_name['ArmKinematics'] = _ARMKINEMATICS

# @@protoc_insertion_point(module_scope)
